# coding: utf-8

# Constants
USER = 'user'
XIMPIA = 'ximpia'
TWITTER = 'twitter'
FACEBOOK = 'facebook'
LINKEDIN = 'linkedin'
GOOGLE = 'google'
EMAIL = 'email'
SMS = 'sms'
READ = 'read'
UPDATE = 'update'
NET = 'net'
DELETE = 'delete'
WF = 'wf'
ZONE = 'zone'
GROUP = 'group'
CONDITION = 'condition'
CONDITIONS = 'conditions'
MENU_NAME = 'menuName'
VIEW = 'view'
SEP = 'sep'

# Params
PARAM_COMMTYPE = 'COMMTYPE'
PARAM_ICON = 'ICON'
PARAM_CHANNEL = 'CHANNEL'
PARAM_META_TYPE = 'META_TYPE'
PARAM_SETTINGS = 'SETTINGS'
PARAM_META = 'META'
PARAM_META_WF = 'META_WF'
PARAM_META_APP = 'META_APP'
PARAM_META_SERVICE = 'META_SERVICE'
PARAM_META_VIEW = 'META_VIEW'
PARAM_MEDIA_TYPE = 'MEDIA_TYPE'

CONDITION_ACTION_RENDER = 'render'
